From 43f09c6abd408eb2e830a131fa2d3710ae7fc6cb Mon Sep 17 00:00:00 2001
From: Ming Yang <yangming73@huawei.com>
Date: Wed, 2 Dec 2020 16:05:51 +0800
Subject: [PATCH 2/2] Alter architercture: move cmdline.rs from macro_vm to
 machine_manager.

1. cmdline.rs is more relative to machine_manager than macro_vm, as functions
  in cmdline.rs are mainly used for parsing arguements for virtual machine instead
  of macro_vm.

2. To be a common part of both macro_vm and stardand vm which will be support in
the near future.

Signed-off-by: Ming Yang <yangming73@huawei.com>
---
 device_model/src/lib.rs                                   | 2 +-
 device_model/src/micro_vm/mod.rs                          | 1 -
 .../src/micro_vm => machine_manager/src}/cmdline.rs       | 8 +++++---
 machine_manager/src/lib.rs                                | 1 +
 src/main.rs                                               | 2 +-
 5 files changed, 8 insertions(+), 6 deletions(-)
 rename {device_model/src/micro_vm => machine_manager/src}/cmdline.rs (99%)

diff --git a/device_model/src/lib.rs b/device_model/src/lib.rs
index 97d3dcc..229a4d7 100644
--- a/device_model/src/lib.rs
+++ b/device_model/src/lib.rs
@@ -46,7 +46,7 @@ mod mmio;
 mod virtio;
 
 pub use error_chain::*;
-pub use micro_vm::{cmdline, main_loop::MainLoop, micro_syscall::register_seccomp, LightMachine};
+pub use micro_vm::{main_loop::MainLoop, micro_syscall::register_seccomp, LightMachine};
 
 use address_space::GuestAddress;
 
diff --git a/device_model/src/micro_vm/mod.rs b/device_model/src/micro_vm/mod.rs
index 94a3e3f..87113b4 100644
--- a/device_model/src/micro_vm/mod.rs
+++ b/device_model/src/micro_vm/mod.rs
@@ -32,7 +32,6 @@ extern crate boot_loader;
 extern crate machine_manager;
 extern crate util;
 
-pub mod cmdline;
 pub mod main_loop;
 pub mod micro_syscall;
 
diff --git a/device_model/src/micro_vm/cmdline.rs b/machine_manager/src/cmdline.rs
similarity index 99%
rename from device_model/src/micro_vm/cmdline.rs
rename to machine_manager/src/cmdline.rs
index f2de7d0..65c9d81 100644
--- a/device_model/src/micro_vm/cmdline.rs
+++ b/machine_manager/src/cmdline.rs
@@ -14,11 +14,13 @@ use std::fs::File;
 use std::io::Read;
 
 use error_chain::bail;
-use machine_manager::config::VmConfig;
-use machine_manager::socket::SocketType;
 use util::arg_parser::{Arg, ArgMatches, ArgParser};
 
-use crate::errors::{Result, ResultExt};
+use crate::{
+    config::VmConfig,
+    errors::{Result, ResultExt},
+    socket::SocketType,
+};
 
 // Read the programe version in `Cargo.toml`.
 const VERSION: Option<&'static str> = option_env!("CARGO_PKG_VERSION");
diff --git a/machine_manager/src/lib.rs b/machine_manager/src/lib.rs
index 1aac109..0d8d91a 100644
--- a/machine_manager/src/lib.rs
+++ b/machine_manager/src/lib.rs
@@ -27,6 +27,7 @@ extern crate log;
 extern crate error_chain;
 extern crate serde_json;
 
+pub mod cmdline;
 pub mod config;
 pub mod machine;
 #[cfg(feature = "qmp")]
diff --git a/src/main.rs b/src/main.rs
index 5546e7e..0ef51f3 100644
--- a/src/main.rs
+++ b/src/main.rs
@@ -22,8 +22,8 @@ use std::sync::{Arc, Mutex};
 
 use vmm_sys_util::terminal::Terminal;
 
-use device_model::cmdline::{check_api_channel, create_args_parser, create_vmconfig};
 use device_model::{register_seccomp, LightMachine, MainLoop};
+use machine_manager::cmdline::{check_api_channel, create_args_parser, create_vmconfig};
 use machine_manager::config::VmConfig;
 #[cfg(feature = "qmp")]
 use machine_manager::qmp::QmpChannel;
-- 
2.27.0

